HELLO_WORLD = """<!DOCTYPE html>
<html lang"de">
    <body>
        <h1>Hallo Welt!</h1>
    </body>
<html>"""

ERROR = """<!DOCTYPE html>
<html lang"de">
    <body>
        <h1>Fehler!</h1>
        <p>Es ist ein Fehler aufgetreten.</p>
    </body>
</html>"""